/**
 * Autor 			: Alexandre Correia - alexandrecorreia@celepar.pr.gov.br
 * Data 			: 00/00/0000
 * Caso de Teste	: EL-938:Adicionar compromisso
 * 
 * Descrio do Processo de Teste Cadastro no TestLink - http://testlink.expressolivre.org/ 
 * 
 * AES DO PASSO
 * P01. Usurio informa um ttulo para o compromisso;
 ***** P02. Usurio entra com o nome de um participante do compromisso;
 ***** P03. Sistema apresenta participantes encontrados para escolha;
 ***** P04. Usurio seleciona participante e o adiciona ao grupo de participantes do compromisso;
 ***** P05. Sistema atualiza lista de participantes do compromisso;
 ***** P06. Usurio retorna ao passo P02 para adicionar novos participantes. Depois de adicionar no mnimo 2 participantes passar ao prximo passo;
 * P07. Usurio seleciona opo para adicionar participantes externos ao compromisso;
 * P08. Sistema apresenta campo para entrar e-mails de participantes externos;
 * P09. Usurio informa e-mails vlidos dos participantes, separados por vrgula;
 * P10. Usurio clica na opo para salvar o compromisso;
 * P11. Sistema salva o compromisso e retorna para a tela da agenda de eventos utilizando a visualizao padro configurada nas preferncias do Usurio
 * P12. Sistema exibe o compromisso no dia selecionado pelo usurio mostrando o horrio inicial e final, o ttulo do compromisso e local
 * P13. Sistema envia uma mensagem aos participantes do compromisso informando a data e local do compromisso;
 **/

package br.gov.serpro.cte.agenda.casoteste;

import java.util.GregorianCalendar;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import br.gov.serpro.cte.agenda.Objetos.AdicionarCompromissoEL951.Campo;
import br.gov.serpro.cte.agenda.Objetos.AdicionarCompromissoEL951.Valor;
import br.gov.serpro.cte.connection.DAOSelenium;
import br.gov.serpro.cte.connection.LoginExpresso;

import com.thoughtworks.selenium.SeleneseTestCase;

public class Test_EL_951_AdicionarCompromissoComParticipantesExternos extends SeleneseTestCase
{
	@Before
	public void setUp() throws Exception
	{
		String url			= "https://cte.serpro.gov.br";
		DAOSelenium conn	= new DAOSelenium( "localhost", 4444, "*pifirefox", url);
		selenium			= conn.newConnection();
	}
	@Test
	public void testa()
	{
		// Logando No Expresso
		selenium.open("/login.php");
		selenium.type("user", LoginExpresso.USER_EXPRESSO.getValue());
		selenium.type("passwd", LoginExpresso.PASSWORD_EXPRESSO.getValue());
		selenium.click("submitit");
		selenium.waitForPageToLoad("30000");
		selenium.click("//html/body/div[@id='toolbar']/table/tbody/tr/td[2]/table/tbody/tr/td[3]/a/img[@id='calendarid']");

		// Data
		GregorianCalendar gc = new GregorianCalendar();
		String	Dia = String.valueOf( gc.get( gc.DAY_OF_MONTH ) );
				Dia = ( Dia.length() > 1 ) ? Dia : "0"+Dia; 
		
		String	Mes = String.valueOf( gc.get( gc.MONTH ) + 1 );
		
		String	Ano = String.valueOf( gc.get( gc.YEAR ) );
		
		//Adicionando um Evento
		selenium.open("/index.php?date=" + Ano + Mes + Dia + "&menuaction=calendar.uicalendar.week");
		selenium.click("//img[@title='Nova Entrada']");
		selenium.waitForPageToLoad("30000");
		
		for( Campo cmp : Campo.values() )
		{
			String cmpName = cmp.name();
				 
			if( cmp.getValue().indexOf("addSelection:") > -1 )
			{	
				AddSelection( cmp.getValue(), getValor( cmp.name() ) );
			}
			
			if( cmp.getValue().indexOf("click:") > -1 )
			{
				Click( cmp.getValue() );
			}
			
			if( cmp.getValue().indexOf("select:") > -1 )
			{
				Select( cmp.getValue(), getValor( cmp.name() ) );
			}
			
			if( cmp.getValue().indexOf("type:") > -1 )
			{
				Type( cmp.getValue(), getValor( cmp.name() ) );
			}
		}
		
		selenium.waitForPageToLoad("15000");

		// Volta a Pgina Inicial do Mdulo
		assertTrue(selenium.getHtmlSource().contains("<div id=\"divAppboxHeader\">Agenda de Eventos</div>"));
		
		// Verifica a hora Inicial e final do Compromisso
		assertTrue( selenium.isTextPresent(Valor.HORA_INICIO.getValue() + ":" + Valor.MINUTO_INICIO.getValue() + 
				 "-" + Valor.HORA_FINAL.getValue() + ":" + Valor.MINUTO_FINAL.getValue()));

		// Verifica o Titulo do Compromisso
		assertTrue( selenium.isTextPresent(Valor.TITULO.getValue()) );
		
		// Verifica Local do Compromisso
		assertTrue( selenium.isTextPresent(Valor.LOCALIZACAO.getValue()) );
		
	}
	
	public String getValor(String cmpName)
	{
		String _return = "";
		
		for( Valor vlr : Valor.values() )
		{
			 String vlrName = vlr.name();
			 
			 if( vlrName.equals( cmpName ) )
			 {
				 _return = vlr.getValue();
			 }
		}
		
		return _return;
	}
	
	public void AddSelection( String locator, String optionLocator )
	{
		selenium.addSelection( locator.substring( 13 , locator.length() ), optionLocator );
	}
	
	public void Click( String locator )
	{
		selenium.click( locator.substring( 6 , locator.length() ) );
	}

	public void Select( String selectLocator, String optionLocator )
	{
		selenium.select( selectLocator.substring( 7 , selectLocator.length() ), optionLocator );
	}

	public void Type( String locator, String value )
	{
		selenium.type( locator.substring( 5 , locator.length() ), value );
	}
	
	@After
	public void tearDown() throws Exception
	{
		selenium.close();
	}
}